@@ -1,7 +1,9 @@
 from .py_fasta_validator import validate_fasta_file
 from .exceptions import FirstCharacterIncorrect, DuplicateIdentifiers, NonSequenceCharacters
+from .version import __version__
 
 __all__ = [
     'validate_fasta_file',
-    'FirstCharacterIncorrect', 'DuplicateIdentifiers', 'NonSequenceCharacters'
-]
\ No newline at end of file
+    'FirstCharacterIncorrect', 'DuplicateIdentifiers', 'NonSequenceCharacters',
+    '__version__'
+]
